@@ -8,7 +8,7 @@ import pandas as pd
 
 from archimedes.data.common import get_api_base_url_v2
 from archimedes.utils import get_end_date, get_start_date
-from archimedes.utils.api_request import make_api_request
+from archimedes.utils.api_request import api
 from archimedes.utils.threaded_executor import execute_many
 from archimedes.utils.utils import datetime_to_iso_format
 
@@ -63,7 +63,7 @@ def forecast_list_ref_times(
         "limit": limit,
     }
 
-    data = make_api_request(
+    data = api.request(
         f"{get_api_base_url_v2()}/forecast/list_ref_times",
         access_token=access_token,
         params=query,
@@ -129,7 +129,7 @@ def forecast_diff(
         "ref_time2": datetime_to_iso_format(ref_time2),
     }
 
-    data = make_api_request(
+    data = api.request(
         f"{get_api_base_url_v2()}/forecast/diff",
         access_token=access_token,
         params=query,
@@ -210,7 +210,7 @@ def forecast_get(
         dict(url=f"{base_url}/forecast/get", access_token=access_token, params=query)
         for query in queries
     ]
-    data = execute_many(make_api_request, params_array)
+    data = execute_many(api.request, params_array)
 
     if len(data) == 0:
         df = pd.DataFrame(
@@ -286,7 +286,7 @@ def forecast_get_by_ref_time_interval(  # pylint:disable=too-many-arguments
         "day_ahead_hour": day_ahead_hour,
     }
 
-    data = make_api_request(
+    data = api.request(
         f"{get_api_base_url_v2()}/forecast/get_by_ref_time_interval",
         access_token=access_token,
         params=query,
