@@ -6,7 +6,7 @@ import pandas as pd
 
 from archimedes.data.common import get_api_base_url_v2
 from archimedes.data.types import PredictionData
-from archimedes.utils.api_request import make_api_request
+from archimedes.utils.api_request import api
 from archimedes.utils.threaded_executor import execute_many
 from archimedes.utils.utils import datetime_to_iso_format
 
@@ -107,7 +107,7 @@ def get_predictions(  # pylint:disable=too-many-arguments
         for query in queries
     ]
 
-    data = execute_many(make_api_request, params_array, _merge_function)
+    data = execute_many(api.request, params_array, _merge_function)
 
     df = pd.DataFrame.from_dict(data)
 
@@ -141,7 +141,7 @@ def get_predictions_ref_dts(prediction_id: str = None, *, access_token: str = No
     if prediction_id:
         query["prediction_id"] = prediction_id
 
-    data = make_api_request(
+    data = api.request(
         f"{get_api_base_url_v2()}/data/get_predictions_ref_dts",
         access_token=access_token,
         params=query,
@@ -189,7 +189,7 @@ def store_prediction(
         "data": data,
     }
 
-    ret = make_api_request(
+    ret = api.request(
         f"{get_api_base_url_v2()}/data/store_prediction",
         method="POST",
         data=json.dumps(payload),
@@ -248,7 +248,7 @@ def store_predictions(
         "data": predictions,
     }
 
-    ret = make_api_request(
+    ret = api.request(
         f"{get_api_base_url_v2()}/data/store_predictions",
         method="POST",
         data=json.dumps(payload),
