@@ -3,12 +3,20 @@ from typing import Dict, TypedDict
 from pandas import Timestamp
 
 
-def PredictionData(TypedDict):
+class PredictionData(TypedDict):
+    """
+    Model for Prediction data
+    """
+
     from_dt: Timestamp
     ref_dt: Timestamp
     run_dt: Timestamp
     data: Dict
 
 
-def Prediction(PredictionData):
+class Prediction(PredictionData):
+    """
+    Model for Prediction
+    """
+
     prediction_id: str
